"""
hollow — Python SDK for Hollow, serverless web perception for AI agents.

Quick start::

    from hollow import HollowClient, run_agent

    # Single page
    client = HollowClient()
    page = client.perceive("https://news.ycombinator.com")
    print(page.gdg_map)

    # Agent task — default Anthropic adapter
    result = run_agent(client, task="What are the top 3 stories on HN?")
    print(result)

    # Agent task — OpenAI
    from hollow import OpenAIAdapter
    result = run_agent(client, task="...", model=OpenAIAdapter(model="gpt-4o"))

    # Agent task — any callable
    result = run_agent(client, task="...", model=lambda msgs: my_model.chat(msgs))
"""

from hollow.client import HollowClient
from hollow.agent import run_agent, AnthropicAdapter, OpenAIAdapter, ModelAdapter
from hollow.types import Action, PerceiveResult, AgentStep

__version__ = "0.2.0"

__all__ = [
    "HollowClient",
    "run_agent",
    "AnthropicAdapter",
    "OpenAIAdapter",
    "ModelAdapter",
    "Action",
    "PerceiveResult",
    "AgentStep",
]
